@@ -12,20 +12,13 @@
 
 from __future__ import absolute_import
 
-try:
-    import six
-except ImportError:  # pragma: no cover
-    import warnings
-    warnings.warn("Ignoring six. Probably setup.py installing package.")
-
-from preggy import create_assertions
+from preggy import create_assertions, fix_string
 
 
 @create_assertions
 def to_equal(topic, expected):
     '''Asserts that `topic == expected`.'''
-    if isinstance(topic, (six.binary_type, )):
-        topic = topic.decode('utf-8')
-    if isinstance(expected, (six.binary_type, )):
-        expected = expected.decode('utf-8')
+    topic = fix_string(topic)
+    expected = fix_string(expected)
+
     return expected == topic
